@@ -2,7 +2,9 @@ package version::regex;
 
 use strict;
 
-our $VERSION = '0.9924_02';
+use vars qw($VERSION $CLASS $STRICT $LAX);
+
+$VERSION = 0.9905;
 
 #--------------------------------------------------------------------------#
 # Version regexp components
@@ -47,8 +49,7 @@ my $LAX_DOTTED_DECIMAL_PART = qr/\.[0-9]+/;
 # Alpha suffix part of lax version number syntax.  Acts like a
 # dotted-decimal part.
 
-#my $LAX_ALPHA_PART = qr/_[0-9]+/;
-my $LAX_ALPHA_PART = qr/(?:_[0-9]+c?|c?)/;
+my $LAX_ALPHA_PART = qr/_[0-9]+/;
 
 #--------------------------------------------------------------------------#
 # Strict version regexp definitions
@@ -56,19 +57,19 @@ my $LAX_ALPHA_PART = qr/(?:_[0-9]+c?|c?)/;
 
 # Strict decimal version number.
 
-our $STRICT_DECIMAL_VERSION =
-    qr/ $STRICT_INTEGER_PART $FRACTION_PART? c? /x;
+my $STRICT_DECIMAL_VERSION =
+    qr/ $STRICT_INTEGER_PART $FRACTION_PART? /x;
 
 # Strict dotted-decimal version number.  Must have both leading "v" and
 # at least three parts, to avoid confusion with decimal syntax.
 
-our $STRICT_DOTTED_DECIMAL_VERSION =
-    qr/ v $STRICT_INTEGER_PART $STRICT_DOTTED_DECIMAL_PART{2,} c? /x;
+my $STRICT_DOTTED_DECIMAL_VERSION =
+    qr/ v $STRICT_INTEGER_PART $STRICT_DOTTED_DECIMAL_PART{2,} /x;
 
 # Complete strict version number syntax -- should generally be used
 # anchored: qr/ \A $STRICT \z /x
 
-our $STRICT =
+$STRICT =
     qr/ $STRICT_DECIMAL_VERSION | $STRICT_DOTTED_DECIMAL_VERSION /x;
 
 #--------------------------------------------------------------------------#
@@ -79,8 +80,8 @@ our $STRICT =
 # allowing an alpha suffix or allowing a leading or trailing
 # decimal-point
 
-our $LAX_DECIMAL_VERSION =
-    qr/ $LAX_INTEGER_PART (?: $FRACTION_PART | \. )? $LAX_ALPHA_PART?
+my $LAX_DECIMAL_VERSION =
+    qr/ $LAX_INTEGER_PART (?: \. | $FRACTION_PART $LAX_ALPHA_PART? )?
 	|
 	$FRACTION_PART $LAX_ALPHA_PART?
     /x;
@@ -91,7 +92,7 @@ our $LAX_DECIMAL_VERSION =
 # enough, without the leading "v", Perl takes .1.2 to mean v0.1.2,
 # so when there is no "v", the leading part is optional
 
-our $LAX_DOTTED_DECIMAL_VERSION =
+my $LAX_DOTTED_DECIMAL_VERSION =
     qr/
 	v $LAX_INTEGER_PART (?: $LAX_DOTTED_DECIMAL_PART+ $LAX_ALPHA_PART? )?
 	|
@@ -104,8 +105,8 @@ our $LAX_DOTTED_DECIMAL_VERSION =
 # The string 'undef' is a special case to make for easier handling
 # of return values from ExtUtils::MM->parse_version
 
-our $LAX =
-    qr/ undef | $LAX_DOTTED_DECIMAL_VERSION | $LAX_DECIMAL_VERSION /x;
+$LAX =
+    qr/ undef | $LAX_DECIMAL_VERSION | $LAX_DOTTED_DECIMAL_VERSION /x;
 
 #--------------------------------------------------------------------------#
 
