@@ -116,12 +116,19 @@ sub currstr {
 }
 
 package version::vpp;
+
+use 5.005_04;
 use strict;
 
 use POSIX qw/locale_h/;
 use locale;
-use vars qw ($VERSION @ISA @REGEXS);
-$VERSION = 0.9904;
+use vars qw($VERSION $CLASS @ISA);
+$VERSION = 0.9905;
+$CLASS = 'version::vpp';
+
+require version::regex;
+*version::vpp::is_strict = \&version::regex::is_strict;
+*version::vpp::is_lax = \&version::regex::is_lax;
 
 use overload (
     '""'       => \&stringify,
@@ -150,6 +157,64 @@ if ($@) {
     ';
 }
 
+sub import {
+    no strict 'refs';
+    my ($class) = shift;
+
+    # Set up any derived class
+    unless ($class eq $CLASS) {
+	local $^W;
+	*{$class.'::declare'} =  \&{$CLASS.'::declare'};
+	*{$class.'::qv'} = \&{$CLASS.'::qv'};
+    }
+
+    my %args;
+    if (@_) { # any remaining terms are arguments
+	map { $args{$_} = 1 } @_
+    }
+    else { # no parameters at all on use line
+	%args =
+	(
+	    qv => 1,
+	    'UNIVERSAL::VERSION' => 1,
+	);
+    }
+
+    my $callpkg = caller();
+
+    if (exists($args{declare})) {
+	*{$callpkg.'::declare'} =
+	    sub {return $class->declare(shift) }
+	  unless defined(&{$callpkg.'::declare'});
+    }
+
+    if (exists($args{qv})) {
+	*{$callpkg.'::qv'} =
+	    sub {return $class->qv(shift) }
+	  unless defined(&{$callpkg.'::qv'});
+    }
+
+    if (exists($args{'UNIVERSAL::VERSION'})) {
+	local $^W;
+	*UNIVERSAL::VERSION
+		= \&{$CLASS.'::_VERSION'};
+    }
+
+    if (exists($args{'VERSION'})) {
+	*{$callpkg.'::VERSION'} = \&{$CLASS.'::_VERSION'};
+    }
+
+    if (exists($args{'is_strict'})) {
+	*{$callpkg.'::is_strict'} = \&{$CLASS.'::is_strict'}
+	  unless defined(&{$callpkg.'::is_strict'});
+    }
+
+    if (exists($args{'is_lax'})) {
+	*{$callpkg.'::is_lax'} = \&{$CLASS.'::is_lax'}
+	  unless defined(&{$callpkg.'::is_lax'});
+    }
+}
+
 my $VERSION_MAX = 0x7FFFFFFF;
 
 # implement prescan_version as closely to the C version as possible
@@ -609,6 +674,11 @@ sub new
 	    $qv = TRUE;
 	}
 
+	if (ref($value) =~ m/ARRAY|HASH/) {
+	    require Carp;
+	    Carp::croak("Invalid version format (non-numeric data)");
+	}
+
 	$value = _un_vstring($value);
 
 	# exponential notation
@@ -806,7 +876,7 @@ sub is_alpha {
 
 sub qv {
     my $value = shift;
-    my $class = 'version';
+    my $class = $CLASS;
     if (@_) {
 	$class = ref($value) || $value;
 	$value = shift;
@@ -814,7 +884,7 @@ sub qv {
 
     $value = _un_vstring($value);
     $value = 'v'.$value unless $value =~ /(^v|\d+\.\d+\.\d)/;
-    my $obj = version->new($value);
+    my $obj = $CLASS->new($value);
     return bless $obj, $class;
 }
 
